==> kdeedu-3.4.1.tar.bz2: kdeedu-3.4.1/kvoctrain/kvoctrain/entry-dialogs/MySpinBox.h <==
/***************************************************************************

    $Id: MySpinBox.h 237589 2003-07-17 12:48:23Z binner $

                    display special spinbox

    -----------------------------------------------------------------------

    begin                : Sat Oct 21 18:02:16 1999
                                           
    copyright            : (C) 1999-2001 Ewald Arnold
                           (C) 2001 The KDE-EDU team
                         
    email                : kvoctrain@ewald-arnold.de                                    

    -----------------------------------------------------------------------

 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/


#include <qspinbox.h>

class QStringlist;

#ifndef MySpinbox_included
#define MySpinbox_included

  class MySpinBox : public QSpinBox {
  public:
    MySpinBox (QWidget* parent = 0, const char* name = 0);

    void setSpecial(const QString &str);
    void setData (QStringList *names, int minValue, int maxValue);
    virtual QString mapValueToText( int value );
    virtual int	    mapTextToValue( bool* ok );

  protected:
    QStringList    *spin_names;
    QString         special_str;
  };

#endif // MySpinbox_included

==> kdeedu-3.5.9.tar.bz2: kdeedu-3.5.9/kvoctrain/kvoctrain/entry-dialogs/MySpinBox.h <==
/***************************************************************************

                    display special spinbox

    -----------------------------------------------------------------------

    begin          : Sat Oct 21 18:02:16 1999

    copyright      : (C) 1999-2001 Ewald Arnold <kvoctrain@ewald-arnold.de>
                     (C) 2001 The KDE-EDU team
                     (C) 2005 Peter Hedlund <peter.hedlund@kdemail.net>

    -----------------------------------------------------------------------

 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/

#ifndef MySpinbox_included
#define MySpinbox_included

#include <qspinbox.h>

class QStringlist;

class MySpinBox : public QSpinBox
{
public:
  MySpinBox (QWidget* parent = 0, const char* name = 0);

  void setSpecial(const QString &str);
  void setData (QStringList *names, int minValue, int maxValue);
  virtual QString mapValueToText( int value );
  virtual int mapTextToValue( bool* ok );

protected:
  QStringList *spin_names;
  QString special_str;
};

#endif // MySpinbox_included
